============
astroimtools
============

|PyPI Version| |CI Status| |Codecov Status| |Stable RTD Status| |Astropy|

Astroimtools is a Python package that provides convenience tools for
working with astronomical images.

.. |PyPI Version| image::  https://img.shields.io/pypi/v/astroimtools.svg?logo=pypi&logoColor=white&label=PyPI
    :target: https://pypi.org/project/astroimtools/
    :alt: PyPI Latest Release

.. |Astropy| image:: https://img.shields.io/badge/powered%20by-AstroPy-orange.svg?style=flat
    :target: https://www.astropy.org/
    :alt: Powered by Astropy

.. |CI Status| image:: https://github.com/spacetelescope/astroimtools/workflows/CI%20Tests/badge.svg#
    :target: https://github.com/spacetelescope/astroimtools/actions
    :alt: CI Status

.. |Codecov Status| image:: https://img.shields.io/codecov/c/github/spacetelescope/astroimtools?logo=codecov
    :target: https://codecov.io/gh/spacetelescope/astroimtools
    :alt: Codecov Status

.. |Stable RTD Status| image:: https://img.shields.io/readthedocs/astroimtools/latest.svg?logo=read%20the%20docs&logoColor=white&label=Docs&version=stable
    :target: https://astroimtools.readthedocs.io/en/stable/
    :alt: Stable Documentation Status
